@@ -13,8 +13,8 @@
 G_BEGIN_DECLS
 
 #define SOUP_MAJOR_VERSION (2)
-#define SOUP_MINOR_VERSION (54)
-#define SOUP_MICRO_VERSION (1)
+#define SOUP_MINOR_VERSION (60)
+#define SOUP_MICRO_VERSION (3)
 
 #define SOUP_CHECK_VERSION(major, minor, micro) \
     (SOUP_MAJOR_VERSION > (major) || \
@@ -63,6 +63,8 @@ G_BEGIN_DECLS
 #define SOUP_VERSION_2_50 (G_ENCODE_VERSION (2, 50))
 #define SOUP_VERSION_2_52 (G_ENCODE_VERSION (2, 52))
 #define SOUP_VERSION_2_54 (G_ENCODE_VERSION (2, 54))
+#define SOUP_VERSION_2_56 (G_ENCODE_VERSION (2, 56))
+#define SOUP_VERSION_2_58 (G_ENCODE_VERSION (2, 58))
 
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target
@@ -329,6 +331,34 @@ G_BEGIN_DECLS
 # define SOUP_AVAILABLE_IN_2_54                 _SOUP_EXTERN
 #endif
 
+#if SOUP_VERSION_MIN_REQUIRED >= SOUP_VERSION_2_56
+# define SOUP_DEPRECATED_IN_2_56                G_DEPRECATED
+# define SOUP_DEPRECATED_IN_2_56_FOR(f)         G_DEPRECATED_FOR(f)
+#else
+# define SOUP_DEPRECATED_IN_2_56
+# define SOUP_DEPRECATED_IN_2_56_FOR(f)
+#endif
+
+#if SOUP_VERSION_MAX_ALLOWED < SOUP_VERSION_2_56
+# define SOUP_AVAILABLE_IN_2_56                 G_UNAVAILABLE(2, 56) _SOUP_EXTERN
+#else
+# define SOUP_AVAILABLE_IN_2_56                 _SOUP_EXTERN
+#endif
+
+#if SOUP_VERSION_MIN_REQUIRED >= SOUP_VERSION_2_58
+# define SOUP_DEPRECATED_IN_2_58                G_DEPRECATED
+# define SOUP_DEPRECATED_IN_2_58_FOR(f)         G_DEPRECATED_FOR(f)
+#else
+# define SOUP_DEPRECATED_IN_2_58
+# define SOUP_DEPRECATED_IN_2_58_FOR(f)
+#endif
+
+#if SOUP_VERSION_MAX_ALLOWED < SOUP_VERSION_2_58
+# define SOUP_AVAILABLE_IN_2_58                 G_UNAVAILABLE(2, 58) _SOUP_EXTERN
+#else
+# define SOUP_AVAILABLE_IN_2_58                 _SOUP_EXTERN
+#endif
+
 SOUP_AVAILABLE_IN_2_42
 guint    soup_get_major_version (void);
 
